==> nono-0.7.2.tar.gz: nono-0.7.2/wx/wxstatuspanel.h <==
//
// nono
// Copyright (C) 2021 nono project
// Licensed under nono-license.txt
//

//
// ステータスパネル
//

#pragma once

#include "wxtextpanel.h"
#include "fdd.h"
#include <array>

class Indicator;
class PowerDevice;
class Syncer;
class Status;
class WXStatusPanel;

// インジケータ情報 (ほぼ構造体)
class Indicator
{
 public:
	// インジケータの識別子
	enum {
		NONE = 0,
		PERF,
		POWER,
		SCSI0,
		SCSI1,
		SCSI2,
		SCSI3,
		SCSI4,
		SCSI5,
		SCSI6,
		SCSI7,
		VBLK0,
		VBLK1,
		VBLK2,
		VBLK3,
		VBLK4,
		VBLK5,
		VBLK6,
		VBLK7,
		LAN0,
		LAN1,
		FDD0,
		FDD1,
		FDD2,
		FDD3,
		NEWSLED1,
		NEWSLED2,
	};
 protected:
	using dispfunc_t = void (WXStatusPanel::*)(const Indicator *);
	using eventfunc_t = void (WXStatusPanel::*)(const Indicator *);
 public:
	Indicator() { }
	// 文字列の長さだけ指定する場合
	Indicator(int id_, dispfunc_t draw_, int minlen_, Status *stat_) {
		id = id_;
		draw = draw_;
		stat = stat_;
		minlen = minlen_;
	}
	// 文字列で指定する場合
	Indicator(int id_, dispfunc_t draw_, const std::string& text_,
		Status *stat_)
		: Indicator(id_, draw_, text_.length(), stat_)
	{
		text = text_;
	}
	virtual ~Indicator() = default;

	// インジケータ識別子
	int id {};

	// 対応する状態
	Status *stat {};

	// 枠内の最小文字列長。
	// 枠の大きさはこの文字列長と text.length() の長いほうで描画される。
	int minlen {};

	// 表示する文字列。
	std::string text {};

	// 描画関数 (必須)
	dispfunc_t draw {};

	// ダブルクリックの処理関数 (必要なら)
	eventfunc_t dclick {};

	// コンテキストメニューの処理関数 (必要なら)
	eventfunc_t contextmenu {};

	// 対応するデバイス (必要なら)
	Device *dev {};

	// ToolTip を表示するためのダミーパネル
	wxPanel *panel {};

	// 枠の位置と大きさは panel.GetRect() で取得できる (実行時に計算する)
	Rect rect {};

 public:
	// SCSI なら SCSI ID を返す。そうでなければ -1 を返す。
	int GetSCSIID() const;

	// FDD ならユニット番号を返す。そうでなければ -1 を返す。
	int GetFDUnit() const;
};

// ステータスパネル
class WXStatusPanel : public WXTextPanel
{
	using inherited = WXTextPanel;

 public:
	WXStatusPanel(wxWindow *parent);
	virtual ~WXStatusPanel() override;

	void FontChanged() override;

 private:
	void OnClose(wxCloseEvent&);
	void OnShow(wxShowEvent&);
	void OnSize(wxSizeEvent&);
	void OnTimer(wxTimerEvent&);
	void OnLeftDClick(wxMouseEvent&);
	void OnContextMenu(wxContextMenuEvent&);
	void OnSCSIMediaChanged(wxCommandEvent&);
	void OnFDDMediaChanged(wxCommandEvent&);
	void OnLEDChanged(wxCommandEvent&);

	bool UpdateStat();
	void Draw() override;
	void InitIndicators();
	void LayoutIndicators();
	void DrawPerf(const Indicator *);
	void DrawSCSI(const Indicator *);
	void DrawVBlk(const Indicator *);
	void DrawNet(const Indicator *);
	void DrawFD(const Indicator *);
	void DrawNewsLED1(const Indicator *);
	void DrawNewsLED2(const Indicator *);
	void DrawPower(const Indicator *);
	void DrawTextLED(const Indicator *, Color fg, Color bg);
	void DClickPerf(const Indicator *);
	void ContextMenuCD(const Indicator *);
	void ContextMenuFD(const Indicator *);

	// 状態
	std::vector<Status*> stats {};

	// インジケータ情報
	std::vector<Indicator*> indicators {};

	// インジケータ表示用
	bool ispower {};
	bool powerled {};
	int perf_mode {};
	int perf_rate {};
	std::array<bool, 8> scsi_loaded {};
	std::array<bool, 4> fd_loaded {};

	// 丸いアクセスマーク (X68k FD 用)
	std::unique_ptr<BitmapI8> accmark /*{}*/;

	// 背景再描画
	bool refresh_background {};

	PowerDevice *power {};
	Syncer *syncer {};

	// タイマー
	wxTimer timer {};

	// イベントテーブル
	wxDECLARE_EVENT_TABLE();

	static const uint8 AccessMark12[];
	static const uint8 AccessMark16[];
	static const uint8 AccessMark24[];
};

==> nono-1.1.1.tar.gz: nono-1.1.1/wx/wxstatuspanel.h <==
//
// nono
// Copyright (C) 2021 nono project
// Licensed under nono-license.txt
//

//
// ステータスパネル
//

#pragma once

#include "wxtextpanel.h"
#include "fdd.h"
#include <array>

class Indicator;
class PowerDevice;
class Syncer;
class Status;
class WXStatusPanel;

// ステータスパネル
class WXStatusPanel : public WXTextPanel
{
	using inherited = WXTextPanel;

 public:
	explicit WXStatusPanel(wxWindow *parent);
	~WXStatusPanel() override;

	void FontChanged() override;

 private:
	void OnClose(wxCloseEvent&);
	void OnShow(wxShowEvent&);
	void OnSize(wxSizeEvent&);
	void OnTimer(wxTimerEvent&);
	void OnLeftDClick(wxMouseEvent&);
	void OnContextMenu(wxContextMenuEvent&);
	void OnSCSIMediaChanged(wxCommandEvent&);
	void OnFDDMediaChanged(wxCommandEvent&);
	void OnLEDChanged(wxCommandEvent&);

	bool UpdateStat();
	void Draw() override;
	void InitIndicators();
	void LayoutIndicators();
	void DrawPerf(const Indicator *);
	void DrawSCSI(const Indicator *);
	void DrawVBlk(const Indicator *);
	void DrawNet(const Indicator *);
	void DrawFD(const Indicator *);
	void DrawNewsLED1(const Indicator *);
	void DrawNewsLED2(const Indicator *);
	void DrawPower(const Indicator *);
	void DrawTextLED(const Indicator *, Color fg, Color bg);
	void DClickPerf(const Indicator *);
	void ContextMenuCD(const Indicator *);
	void ContextMenuFD(const Indicator *);

	// 状態
	std::vector<Status*> stats {};

	// インジケータ情報
	std::vector<Indicator*> indicators {};

	// インジケータ表示用
	bool ispower {};
	bool powerled {};
	uint perf_mode {};
	uint perf_rate {};
	std::array<bool, 8> scsi_loaded {};
	std::array<bool, 4> fd_loaded {};

	// 丸いアクセスマーク (X68k FD 用)
	std::unique_ptr<BitmapI8> accmark /*{}*/;

	// 背景再描画
	bool refresh_background {};

	PowerDevice *power {};
	Syncer *syncer {};

	// タイマー
	wxTimer timer {};

	// イベントテーブル
	wxDECLARE_EVENT_TABLE();

	static const uint8 AccessMark12[];
	static const uint8 AccessMark16[];
	static const uint8 AccessMark24[];
};
